==> swscanner_0.1.8.orig.tar.gz: swscanner-0.1.8/src/scanning.h <==
/***************************************************************************
 *   Copyright (C) 2004 by Ivan Forcada Atienza                            *
 *   ivan@forcada.info                                                     *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#include <qstring.h>
#include <qvariant.h>
#include <qstringlist.h>
#include "apentry.h"
#include "aplist.h"
#include "config.h"
#include <unistd.h>
#include "iwlib.h"

int print_scanning_info(int, char *, APList *);
int print_scanning_token(struct iw_event *, int, struct iw_range *, int);
void start_scan(char *, APList *);
void GetWirelessInterfacesNames_new (char* Names, int* Number);
void GetWirelessInterfacesNames_old (char* Names, int *Number);
int iw_get_info(int skfd, char * ifname, struct wireless_info * info);

==> swscanner_0.2.2.orig.tar.gz: swscanner-0.2.2/src/scanning.h <==
/***************************************************************************
 *   Copyright (C) 2004 by Ivan Forcada Atienza                            *
 *   ivan@forcada.info                                                     *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#include <qstring.h>
#include <qvariant.h>
#include <qstringlist.h>
#include "apentry.h"
#include "aplist.h"
#include "config.h"
#include <unistd.h>
#include "iwlib.h"

int print_scanning_info(int, char *, APList *);
int print_scanning_token(struct iw_event *, int, struct iw_range *, int);
int start_scan(char *, APList *);
void GetWirelessInterfacesNames_new (char* Names, int* Number);
void GetWirelessInterfacesNames_old (char* Names, int *Number);
int iw_get_info(int skfd, char * ifname, struct wireless_info * info);
